## 新闻通讯

接口：major_news

描述：获取长篇通讯信息，覆盖主要新闻资讯网站，提供超过8年历史新闻。

限量：单次最大400行记录，可循环提取保存到本地。

积分：本接口需单独开权限（跟积分没关系），具体请参阅权限说明 







输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| src | str | N | 新闻来源（新华网、凤凰财经、同花顺、新浪财经、华尔街见闻、中证网、财新网、第一财经、财联社） |
| start_date | str | N | 新闻发布开始时间，e.g. 2018-11-21 00:00:00 |
| end_date | str | N | 新闻发布结束时间，e.g. 2018-11-22 00:00:00 |







输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| title | str | Y | 标题 |
| content | str | N | 内容 (默认不显示，需要在fields里指定) |
| pub_time | str | Y | 发布时间 |
| src | str | Y | 来源网站 |







接口调用

```python
pro = ts.pro_api()

df = pro.major_news(src='', start_date='2018-11-21 00:00:00', end_date='2018-11-22 00:00:00')

#提取新闻内容
df = pro.major_news(src='', start_date='2018-11-21 00:00:00', end_date='2018-11-22 00:00:00', fields='title,content')
```







数据样例

```python
title  ...                                   src_site
0                     旺能环境：中标2.5亿元蚌埠市餐厨废弃物及污泥处理特许经营项目  ...    益盟操盘手
```